@@ -1,8 +1,7 @@
 package Method::Workflow::Case::Action;
 use strict;
 use warnings;
-use Method::Workflow;
-use base 'Method::Workflow::Case';
+use Method::Workflow::SubClass;
 
 keyword 'action';
 
